'use strict';

/**
 * Compares two values.
 * @param a a value
 * @param b another value
 * @returns a<b: -1, a=b: 0, a>b: 1
 */
function cmp(a, b) {
    return a < b ? -1 : (a > b ? 1 : 0);
}

/**
 * Searches a value from left.
 * @param x an array
 * @param v search value
 * @param fn compare function (a, b)
 * @returns index of value, -1 if not found
 */
function search(x, v, fn = null) {
    var fn = fn || cmp;
    for (var i = 0, I = x.length; i < I; i++)
        if (fn(x[i], v) === 0)
            return i;
    return -1;
}

/**
 * Checks if array has a value.
 * @param x an array
 * @param v value?
 * @param fn compare function (a, b)
 */
function isValue(x, v, fn = null) {
    return search(x, v, fn) >= 0;
}

module.exports = isValue;
